summaryrefslogtreecommitdiff
path: root/tex/context/base/mkiv/node-fnt.lua
diff options
context:
space:
mode:
authorHans Hagen <pragma@wxs.nl>2019-04-12 18:03:49 +0200
committerContext Git Mirror Bot <phg@phi-gamma.net>2019-04-12 18:03:49 +0200
commit171f7b525a5f7ddfb1631501cbc2d09722de4018 (patch)
tree594ab978abdaf0b3b42b1a5da96d2954e0d06159 /tex/context/base/mkiv/node-fnt.lua
parent64f6e8fc0c6cb9254a6fe3db0b4ab31c51cf8524 (diff)
downloadcontext-171f7b525a5f7ddfb1631501cbc2d09722de4018.tar.gz
2019-04-12 17:51:00
Diffstat (limited to 'tex/context/base/mkiv/node-fnt.lua')
-rw-r--r--tex/context/base/mkiv/node-fnt.lua11
1 files changed, 6 insertions, 5 deletions
diff --git a/tex/context/base/mkiv/node-fnt.lua b/tex/context/base/mkiv/node-fnt.lua
index 01d7e42e5..25254009f 100644
--- a/tex/context/base/mkiv/node-fnt.lua
+++ b/tex/context/base/mkiv/node-fnt.lua
@@ -43,7 +43,6 @@ local handlers = nodes.handlers
local nuts = nodes.nuts
-local getattr = nuts.getattr
local getid = nuts.getid
local getsubtype = nuts.getsubtype
local getdisc = nuts.getdisc
@@ -51,7 +50,9 @@ local getnext = nuts.getnext
local getprev = nuts.getprev
local getboth = nuts.getboth
local getdata = nuts.getdata
+local getglyphdata = nuts.getglyphdata
----- getdisc = nuts.getdisc
+
local setchar = nuts.setchar
local setlink = nuts.setlink
local setnext = nuts.setnext
@@ -179,7 +180,7 @@ local function start_trace(head)
local char, id = isglyph(n)
if char then
local font = id
- local attr = getattr(n,0) or 0
+ local attr = getglyphdata(n) or 0
report_fonts("font %03i, dynamic %03i, glyph %C",font,attr,char)
elseif id == disc_code then
report_fonts("[disc] %s",nodes.listtoutf(n,true,false,n))
@@ -316,8 +317,8 @@ do
-- metafun manual (with some 2500 single char lists) the difference is just noise.
for n, char, font in nextchar, head do
- -- local attr = (none and prevattr) or getattr(n,0) or 0 -- zero attribute is reserved for fonts in context
- local attr = getattr(n) or 0 -- zero attribute is reserved for fonts in context
+ -- local attr = (none and prevattr) or getglyphdata(n) or 0 -- zero attribute is reserved for fonts in context
+ local attr = getglyphdata(n) or 0 -- zero attribute is reserved for fonts in context
if font ~= prevfont or attr ~= prevattr then
prevfont = font
prevattr = attr
@@ -440,7 +441,7 @@ do
firstnone = nil
basefont = nil
for n, char, font in nextchar, r do
- local attr = getattr(n) or 0 -- zero attribute is reserved for fonts in context
+ local attr = getglyphdata(n) or 0 -- zero attribute is reserved for fonts in context
if font ~= prevfont or attr ~= prevattr then
prevfont = font
prevattr = attr